@@ -2,14 +2,10 @@ import inspect
 
 from astroid import nodes
 from pylint.checkers import BaseChecker
-from pylint.checkers.utils import check_messages
-from pylint.interfaces import IAstroidChecker
+from pylint.checkers.utils import only_required_for_messages
 
 
 class ForbiddenImportChecker(BaseChecker):
-
-    __implements__ = IAstroidChecker
-
     name = "forbidden_import"
     msgs = {
         "E9999": (
@@ -42,14 +38,14 @@ class ForbiddenImportChecker(BaseChecker):
     # this is important so that your checker is executed before others
     priority = -1
 
-    @check_messages("forbidden-import")
+    @only_required_for_messages("forbidden-import")
     def visit_import(self, node):
         """visit an Import node"""
         temp = [
             name
             for name in node.names
-            if name[0] not in self.config.allowed_import_modules
-            and name[0] not in self.config.extra_imports
+            if name[0] not in self.linter.config.allowed_import_modules
+            and name[0] not in self.linter.config.extra_imports
         ]
 
         if temp != []:
@@ -59,16 +55,16 @@ class ForbiddenImportChecker(BaseChecker):
                 args=(", ".join(map(lambda x: x[0], temp)), node.lineno),
             )
 
-    @check_messages("forbidden-import")
+    @only_required_for_messages("forbidden-import")
     def visit_importfrom(self, node):
         """visit an ImportFrom node"""
         if (
-            node.modname not in self.config.allowed_import_modules
-            and node.modname not in self.config.extra_imports
+            node.modname not in self.linter.config.allowed_import_modules
+            and node.modname not in self.linter.config.extra_imports
         ):
             self.add_message("forbidden-import", node=node, args=(node.modname, node.lineno))
 
-    @check_messages("forbidden-import")
+    @only_required_for_messages("forbidden-import")
     def visit_call(self, node):
         if isinstance(node.func, nodes.Name):
             name = node.func.name
@@ -77,8 +73,8 @@ class ForbiddenImportChecker(BaseChecker):
             if not (name in node.frame() or name in node.root()):
                 if name == "__import__":
                     if (
-                        node.args[0].value not in self.config.allowed_import_modules
-                        and node.args[0].value not in self.config.extra_imports
+                        node.args[0].value not in self.linter.config.allowed_import_modules
+                        and node.args[0].value not in self.linter.config.extra_imports
                     ):
                         args = (node.args[0].value, node.lineno)
                         # add the message
